import React, { useState, useCallback, useEffect } from 'react';
import ReactDropdown from 'react-dropdown';
import ReactDOM from 'react-dom';
import {max,scaleSqrt, scaleOrdinal  } from 'd3';
import { useGeo } from './useGeo';
import { useData } from './useData';
import { Marks } from './Marks';
import { ColorLegend } from './ColorLegend';


const menuHeight = 80;
const width = 960;
const height = 500 - menuHeight;
const margin = { top: 20, right: 250, bottom: 10, left: 10 };
const xAxisLabelOffset = 50;
const yAxisLabelOffset = 45;


const attributes = [
  { value: 'flee', label: 'Flee Status' },
  { value: 'armed', label: 'Armed Status' },
  { value: 'race', label: 'Race' },
  { value: 'gender', label: 'Gender' },
  { value: 'threat_level', label: 'Threat Level' },
  { value: 'body_camera', label: 'Body Camera' },
  { value: 'signs_of_mental_illness', label: 'Mental Illness' }
];

const getLabel = value => {
  for (let i = 0; i < attributes.length; i++) {
    if (attributes[i].value === value) {
      return attributes[i].label;
    }
  }
};

const App = () => {
  const USGeo = useGeo();
  const data = useData();
  
  const initAttribute = 'race';
  const [groupAttribute, setGroupAttribute] = useState(initAttribute);
  const groupValue = d => d.category;
  const groupLabel = getLabel(groupAttribute);

  if (!USGeo || !data) {
    return <pre>Loading...</pre>;
  }
  
  const colorValue = d => d[groupAttribute];
  
  const colorScale = scaleOrdinal()
    .domain(data.map(colorValue))
    .range([
      '#e31a1c', //red
      '#1f78b4', //blue
      '#33a02c', //green
      '#ff7f00', //orange
 
    ]);
  
  console.log(colorScale.domain());
  
  const dataByGroup = d3.nest()
  	.key(function(d) {return d[groupAttribute];})
  	.rollup(function(v) { return v.length;})
  	.entries(data)
  	.map(d => {
    	return {
        category: d.key,
        count: d.value}
      });
  

  const dataByState = d3.nest()
  	.key(function(d) {return d.state;})
  	.rollup(function(v) { return v.length;})
  	.entries(data)
  	.map(d => {
    	return {
        state: d.key,
        count: d.value}
      })
    

  return (
    <>
      <div className="menus-container" transform="translate(40)">
        <span className="dropdown-label">Category:</span>
        <ReactDropdown
          options={attributes}
          value={groupAttribute}
          onChange={({ value }) => setGroupAttribute(value)}
        />
      </div>
      
      <svg width={width} height={height-0}>
        <g transform={`translate(${innerWidth - 175}, 75)`}>
          <text
            x={35}
            y={-25}
            className="axis-label"
            textAnchor="middle"
          >
            {getLabel(groupAttribute)}
          </text>
          <ColorLegend
            tickSpacing={22}
            tickTextOffset={12}
            tickSize={7}
            colorScale={colorScale}
          />
        </g>
        
        <Marks transform={`translate(-50,0)`}
          USGeo={USGeo} 
          data={data}
          width={width}
          height={height}
          margin={margin}
          colorScale={colorScale}
          groupAttribute={groupAttribute}
        />
        
      </svg>
      
      
    </>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
